@@ -1,8 +1,8 @@
 package HTTP::QuickBase;
 
-#Version $Id: QuickBase.pm,v 1.26 2001/04/17 19:54:49 cvonroes Exp $
+#Version $Id: QuickBase.pm,v 1.27 2001/05/07 17:57:30 cvonroes Exp $
 
-( $VERSION ) = '$Revision: 1.26 $ ' =~ /\$Revision:\s+([^\s]+)/;
+( $VERSION ) = '$Revision: 1.27 $ ' =~ /\$Revision:\s+([^\s]+)/;
 
 use strict;
 use LWP::UserAgent;
@@ -13,6 +13,10 @@ use LWP::UserAgent;
 
 HTTP::QuickBase - Create a web shareable database in under a minute
 
+=head1 VERSION
+
+$Revision: 1.27 $
+
 =head1 SYNOPSIS
 
  #see http://developer.intuit.com/quickbase for details of the underlying API
@@ -101,7 +105,6 @@ HTTP::QuickBase - Create a web shareable database in under a minute
  #look at the URL in the browser "Address" window. The View design page is accessible from any database home
  #page by clicking on VIEWS at the top left and then clicking on "New View..." in the lower left.
 
-
 =head1 REQUIRES
 
 Perl5.005, LWP::UserAgent, Crypt::SSLeay (optional unless you want to talk to QuickBase via HTTPS)
@@ -562,7 +565,9 @@ $content =    "<qdbapi>".
               " <rid>$rid</rid>".
               "</qdbapi>";
 	my $res = $self->PostAPIURL ($QuickBaseDBid, "API_GetRecordInfo", $content);
-	@record=$res->content =~ /<([A-Z\-\.0-9]+)>([^<]*)<\/\1>/isg;
+	my $recordXML = $res->content;
+	$recordXML =~ s/<br\/>/\n/ig;
+	@record = $recordXML =~ /<([A-Z\-\.0-9]+)>([^<]*)<\/\1>/isg;
 	my $count = 0;
 	my $record;
 
@@ -1155,7 +1160,7 @@ sub xml_escape ($rest) {
 sub xml_unescape ($rest) {
     my ($self, $rest) = @_;
 	unless(defined($rest)){return "";}
-    $rest   =~ s/<br\/>//ig;
+    $rest   =~ s/<br\/>/\n/ig;
     $rest   =~ s/&lt;/</g;
     $rest   =~ s/&gt;/>/g;
     $rest   =~ s/&amp;/&/g;
